# MkDocs with Tailscale Integration

This project sets up a MkDocs instance with Tailscale VPN integration using Docker Compose. It creates a secure, private network connection for your MkDocs instance using Tailscale.

## Prerequisites

- Docker and Docker Compose installed on your system
- A Tailscale account and auth key (get one from https://login.tailscale.com/admin/authkeys)
- Basic understanding of Docker and networking concepts

## Project Structure
```
ts-mkdocs/
├── docker-compose.yml
├── tailscale/
│   ├── tailscale-data/     # Persistent Tailscale state
│   └── config/             # Tailscale configuration files
└── mkdocs/
    ├── docs/               # MkDocs content files
    └── mkdocs.yml          # MkDocs config file
```

## Setup Instructions

1. **Clone the Repository**
   ```bash
   git clone https://gitea.damconsulting.llc/DAM/ts-mkdocs
   cd ts-mkdocs
   ```
2. Create Required Directories
    ```bash
    mkdir -p tailscale/tailscale-data
    ```
3. Configure Tailscale
    - Replace `{{YOUR_TAILSCALE_AUTHKEY}}` in the docker-compose.yml with your actual Tailscale auth key
    - Optionally, update the file in `tailscale/config/serve.json` if you need specific Tailscale serve configurations
        - CAUTION: Changing `"${TS_CERT_DOMAIN}:443": false` to `true` will expose the service to the internet

4. Configure MkDocs
    - A basic configuration has been provided.
    - See the [documentation](https://www.mkdocs.org/getting-started/#creating-a-new-project) for learning how to add content

5. Start the Services
    ```bash
    docker compose up -d
    ```

6. Wait for Certificate to propagate [~2m] 

7. Login 
    - After starting the services your service should be available via tailnet at https://mkdocs.{{YOUR_TAILNET_DOMAIN}}.ts.net ie https://mkdocs.tail12345.ts.net/

## Services

### mkdocs-ts (Tailscale)

- Runs Tailscale VPN client
- Image: tailscale/tailscale:latest
- Container name: mkdocs-ts
- Hostname: mkdocs
- Requires NET_ADMIN and SYS_MODULE capabilities
- Persists state in ./tailscale/tailscale-data
- Uses configuration from ./tailscale/config

### mkdocs

- Depends on mkdocs-ts service

## Usage

- After starting the services your service should be available via tailnet at `https://mkdocs.{{YOUR_TAILNET_DOMAIN}}.ts.net` ie `https://mkdocs.tail12345.ts.net/`
- To manually get the Tailscale IP/hostname of your container:
    ```bash
    docker logs mkdocs-ts
    ```
    Look for the Tailscale IP address in the logs.

## Optional Features

- Uncomment and adjust the ports mapping if you need direct access (without Tailscale):
    ```yaml
    ports:
    - 8000:8000
    ```
- Stopping the Services
    ```bash
    docker compose down
    ```

## Troubleshooting
- Check container logs:
    ```bash
    docker logs mkdocs-ts
    docker logs mkdocs
    ```
- Ensure your Tailscale auth key is valid and not expired
- Verify the configuration files have proper permissions
- Make sure required directories exist before starting

## Notes
- The MkDocs service uses the Tailscale service's network stack via `network_mode: service:mkdocs-ts`
- Direct port mapping is disabled by default as Tailscale handles the networking
- Services restart automatically unless explicitly stopped
- For more information:
    - Tailscale [documentation](https://tailscale.com/kb/)
    - MkDocs [documentation](https://www.mkdocs.org/getting-started/#creating-a-new-project)
    - MkDocs [repository](https://github.com/mkdocs/mkdocs)